pub struct BuildSession {
pub folder: TempDir,
pub open_count: AtomicUsize,
pub pinned: AtomicBool,
}Expand description
Allows creating files/folders in a Snap folder (which is normally read only)
When a user uses touch/mkdir/ln a build folder is creates in repo_dir/build
Any files or folders created in the Snap folder, are actually created in repo_dir/build/build_
The file system then redirects them to show to be inside the Snap folder
Fields
folder: TempDirRelative path to tempdir
open_count: AtomicUsizepinned: AtomicBoolImplementations